@@ -11,9 +11,10 @@ import pltrdy.wc  # noqa F401
 import pltrdy.quiet
 import pltrdy.tmpdir
 import pltrdy.types
+import pltrdy.cmd
 import pltrdy.git
 
 from pltrdy.describe import describe_str, describe_lines, describe, tab_print
 from pltrdy.reload import reload_class
 
-__version__ = "0.3.8"
+__version__ = "0.3.9.1"
